# Description
Python program to print on terminal a MJD calendar.

# Usage
Basic usage, which prints current month: `python -m pymjdcal`

To print a specific month, pass year and month number as argument, e.g.
`python -m pymjdcal 2000 1`
